// ------------------------------------------------------------------------------------
// JavaORB 2.0
//
//									CosNaming Browser
//
// (c) 1998, 1999 by Jerome DANIEL
// ------------------------------------------------------------------------------------

import javax.swing.*;
import javax.swing.tree.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

/**
 * This class is a dialog box to get information about a naming context
 * 
 * @author	Jerome DANIEL
 * @version	2.0
 */
public class NamingContextDialog extends JDialog
{
	/**
	 * Reference to the data
	 */
	private JTextField _name;
	private JTextField _kind;

	/**
	 * Flag that precises if the cancel button was used
	 */
	private boolean cancel;

	/**
	 * Constructor
	 */
	public NamingContextDialog( java.awt.Frame Owner, String title )
	{
		super(Owner, title, true );
	
		buildDialog("", "");
	}
	
		
	/**
	 * Constructeur
	 */
	public NamingContextDialog( java.awt.Frame Owner, String title, String initName, String initKind )
	{		
		super(Owner, title, true );

		buildDialog(initName, initKind);
	}
	
	/**
	 * Build the dialog window
	 */
	public void buildDialog( String initName, String initKind )
	{
		setSize(500,150);
		
		JPanel panel = new JPanel(false);

		getContentPane().add("Center", panel);

		panel.setLayout( new java.awt.BorderLayout() );

		// ----------------------------
		// Add Name and Kind fields
		// ----------------------------

		JPanel data = new JPanel(false);
		
		java.awt.GridBagConstraints c2 = new java.awt.GridBagConstraints();
		c2.fill = java.awt.GridBagConstraints.BOTH;
		c2.insets = new java.awt.Insets(5, 5, 5, 5);
		
		java.awt.GridBagLayout dataGridbag = new java.awt.GridBagLayout();		
		data.setLayout( dataGridbag );				

		// Name field
		_name = new JTextField(initName);		
		addToPanel(data, new JLabel("Naming context name"), dataGridbag, c2, 0, 1);		
		addToPanel(data, _name, dataGridbag, c2, 2, java.awt.GridBagConstraints.REMAINDER );				

		// Kind field
		
		_kind = new JTextField(initKind);
		addToPanel(data, new JLabel("Naming context kind"), dataGridbag, c2, 0, 1);		
		addToPanel(data, _kind, dataGridbag, c2, 2, java.awt.GridBagConstraints.REMAINDER );				
				
		// --------------------------------
		// Add OK and CANCEL buttons
		// --------------------------------

		JPanel buttons = new JPanel(false);
		
		buttons.setLayout( new java.awt.GridLayout(1,2) );
		buttons.setBorder( new javax.swing.border.EmptyBorder(0,10,5,10) );		

		JButton ok = new JButton("Ok");
		buttons.add(ok);		
		ok.addActionListener( new OkAction() );

		JButton cancel = new JButton("Cancel");
		buttons.add(cancel);
		cancel.addActionListener( new CancelAction() );

		panel.add("Center",data);
		panel.add("South", buttons);			
	}

	/**
	 * Return the naming context name
	 */
	public String getName()
	{
		return _name.getText();
	}

	/**
	 * Return the naming context kind
	 */
	public String getType()
	{
		return _kind.getText();
	}

	/**
	 * Return the flag that precises id the cancel button was used
	 */
	public boolean cancelButton()
	{
		return cancel;
	}

	/**
	 * Event managment for OK
	 */
	public class OkAction extends Object implements ActionListener
	{
		public void actionPerformed( ActionEvent e )
		{
			hide();
			cancel = false;
		}
	}

	/**
	 * Event managment for CANCEL
	 */
	public class CancelAction extends Object implements ActionListener
	{
		public void actionPerformed( ActionEvent e )
		{
			hide();
			cancel = true;
		}
	}
	
	/**
	 * This function adds to a panel a new component with a grid bag constraint
	 */
	private void addToPanel( javax.swing.JPanel panel, 
							 javax.swing.JComponent comp, 
							 java.awt.GridBagLayout gridbag, 
							 java.awt.GridBagConstraints c, 
							 int weightx, int gridwidth )
    {
        c.weightx = weightx;
        c.gridwidth = gridwidth;
        gridbag.setConstraints(comp, c);
        panel.add(comp);
    }

	/**
	 * This function is used to display the windows at the screen center
	 */
    public void show()
    {
		java.awt.Dimension screenSize = getToolkit().getScreenSize();
        setLocation((screenSize.width - getSize().width) / 2 , (screenSize.height - getSize().height) / 2);
        
	    super.show();
	}
}