// ===========================================================
// 
// This example shows how to use an Adapter Activator
//
// Jerome DANIEL
// ===========================================================

/*-----------------------------------------------------------*\
 *						Server implementation				 *
\*-----------------------------------------------------------*/

public class Server
{
	public static void main( String args[] )
	{
		// Initialize the ORB
		org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init(args,null);


		// Resolve the RootPOA
		org.omg.PortableServer.POA rootPOA = null;
		try
		{
			org.omg.CORBA.Object objPoa = orb.resolve_initial_references("RootPOA");

			rootPOA = org.omg.PortableServer.POAHelper.narrow(objPoa);
		}
		catch ( org.omg.CORBA.ORBPackage.InvalidName ex )
		{
		}
		
		try
		{
			// Defined new POA policies
			org.omg.CORBA.Policy [] policies = new org.omg.CORBA.Policy[1];
			
			policies[0] = 
				rootPOA.create_lifespan_policy( 
					org.omg.PortableServer.LifespanPolicyValue.PERSISTENT );

			
			// Create the first POA
			org.omg.PortableServer.POA firstPOA = rootPOA.create_POA("firstPOA", rootPOA.the_POAManager(), policies);
			
			// Create the second POA
			org.omg.PortableServer.POA secondPOA = firstPOA.create_POA("secondPOA", rootPOA.the_POAManager(), policies);

			// Create Adapter Activator
			AdpActivator activator = new AdpActivator();

			// Set the Adapter Activator
			rootPOA.the_activator( activator._this(orb) );

			// Create the Servant
			CalculatriceImpl calc = new CalculatriceImpl();

			// Activate the Servant
			byte [] servantId = "myObject".getBytes();
			
			secondPOA.activate_object_with_id( servantId, calc );
			
			// Get the servant reference
			org.omg.CORBA.Object obj = secondPOA.id_to_reference(servantId);

			// Transform the reference to string
			String reference = orb.object_to_string(obj);

			// Export into a file the object reference
			try
			{
				java.io.FileOutputStream file = new java.io.FileOutputStream("ObjectId");
				java.io.PrintStream pfile=new java.io.PrintStream(file);
				pfile.println(reference);
			}
			catch ( java.io.IOException ex )
			{
				System.out.println("Unable to export the server reference");
			}
			
			// Destroy the first POA
			firstPOA.destroy(true, true);

			// Activate le POA by its manager way
			rootPOA.the_POAManager().activate();

			// The server is now ready
			System.out.println("The server is ready...");

			// Run and wait for invocations
			orb.run();
		}
		catch ( java.lang.Exception ex )
		{
			System.out.println("An exception has been intercepted");
			ex.printStackTrace();
		}

	}
}