// ===========================================================
//
// This example is extracted from CORBA Specification  9.6.10
// It shows how to use a single servant to manage several
// objects
//
// Jerome DANIEL
// ===========================================================

import java.io.*;

public class FileSystemImpl extends FileSystemPOA
{

	/**
	 * File descriptor list
	 */
	protected static java.util.Vector _liste;

	/**
	 * Reference to POA
	 */
	private org.omg.PortableServer.POA _poa;

	/**
	 * Constructor
	 *
	 * @param	poa		reference to POA
	 */
	public FileSystemImpl( org.omg.PortableServer.POA poa )
	{
		_poa = poa;
		_liste = new java.util.Vector();

		try
		{
			poa.set_servant ( new FileDescriptorImpl(poa) );
		}
		catch ( org.omg.PortableServer.POAPackage.WrongPolicy ex )
		{
			System.out.println("Unable to set default servant because");
			System.out.println("this POA does not have the good policies");
			System.exit(0);			
		}
	}

	/**
	 * Operation open
	 *
	 * This operation opens a file with specified flags then returns
	 * a file descriptor.
	 *
	 * @param	file_name	the file name
	 * @param	flags		the operation flags
	 * @return	a descriptor to open file
	 */
	public FileDescriptor open(java.lang.String file_name, int flags)
	{
		DataInputStream file;
		org.omg.CORBA.Object obj;
		
		try
		{
			file = new DataInputStream(
			           new BufferedInputStream(
						   new FileInputStream(file_name)));
		}
		catch ( java.io.IOException ex )
		{
			System.out.println("Unable to open file : "+file_name);
			return null;
		}
		
		_liste.addElement ( file );

		byte [] oid = (new String( new Integer(_liste.size()).toString() )).getBytes();				

		try
		{	
			obj = _poa.create_reference_with_id(oid,"IDL:FileDescriptor:1.0");
		}
		catch ( org.omg.PortableServer.POAPackage.WrongPolicy ex )
		{
			System.out.println("Unable to create the reference because the POA");
			System.out.println("does not have the good policies");

			return null;
		}

		return FileDescriptorHelper.narrow( obj );
	}
}
