// ===========================================================
//
// This example is extracted from CORBA Specification  9.6.10
// It shows how to use a single servant to manage several
// objects
//
// Jerome DANIEL
// ===========================================================

/*----------------------------------------------------------*\
 |					SERVEUR IMPLEMENTATION				    |
\*----------------------------------------------------------*/

public class Server
{
	public static void main( String args[] )
	{
		// Initiliaze the ORB
		org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init(args,null);

		// Resolve the RootPOA
		org.omg.PortableServer.POA rootPOA = null;
		try
		{
			org.omg.CORBA.Object objPoa = orb.resolve_initial_references("RootPOA");

			rootPOA = org.omg.PortableServer.POAHelper.narrow(objPoa);
		}
		catch ( org.omg.CORBA.ORBPackage.InvalidName ex )
		{
		}
		
		try
		{
			// Define policies of the new POA
			org.omg.CORBA.Policy [] policies = new org.omg.CORBA.Policy[3];

			policies[0] = 
				rootPOA.create_id_uniqueness_policy( 
					org.omg.PortableServer.IdUniquenessPolicyValue.MULTIPLE_ID );

			policies[1] = 
				rootPOA.create_request_processing_policy( 
					org.omg.PortableServer.RequestProcessingPolicyValue.USE_DEFAULT_SERVANT );
					
			policies[2] =
				rootPOA.create_id_assignment_policy(
					org.omg.PortableServer.IdAssignmentPolicyValue.USER_ID );
			

			// Create the new POA
			org.omg.PortableServer.POA childPOA = rootPOA.create_POA("MyPOA", rootPOA.the_POAManager(), policies);

			// Instanciante FileSystemImpl
			FileSystemImpl fileSys = new FileSystemImpl( childPOA );
		
			// Create an Object ID
			byte [] servantId = ( new String("FileSystem") ).getBytes();

			// Activate the servant into childPOA 
			childPOA.activate_object_with_id(servantId,fileSys);

			// Get the servant reference 
			org.omg.CORBA.Object obj = childPOA.id_to_reference(servantId);
									
			String reference = orb.object_to_string(obj);

			// Export into a file the servant reference 
			try
			{
				java.io.FileOutputStream file = new java.io.FileOutputStream("ObjectId");
				java.io.PrintStream pfile=new java.io.PrintStream(file);
				pfile.println(reference);
			}
			catch ( java.io.IOException ex )
			{
				System.out.println("Impossible d'exporter la reference du serveur");
			}

			// Activate POA by its manager way
			rootPOA.the_POAManager().activate();

			System.out.println("The server is ready...");

			// Run and wait for invocations
			orb.run();
		}
		catch ( java.lang.Exception ex )
		{
			System.out.println("An exception has been intercepted");
			ex.printStackTrace();
		}

	}
}