// =============================================================
// This is a simple example for a servant locator implementation
//
// Jerome DANIEL
// =============================================================

/*-----------------------------------------------------------*\
 *						Server implementation				 *
\*-----------------------------------------------------------*/

public class Server
{
	public static void main( String args[] )
	{
		// Initialize the ORB
		org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init(args,null);


		// Resolve the RootPOA
		org.omg.PortableServer.POA rootPOA = null;
		try
		{
			org.omg.CORBA.Object objPoa = orb.resolve_initial_references("RootPOA");

			rootPOA = org.omg.PortableServer.POAHelper.narrow(objPoa);
		}
		catch ( org.omg.CORBA.ORBPackage.InvalidName ex )
		{
		}
		
		try
		{
			// Defined new POA policies
			org.omg.CORBA.Policy [] policies = new org.omg.CORBA.Policy[3];

			policies[0] = 
				rootPOA.create_servant_retention_policy( 
					org.omg.PortableServer.ServantRetentionPolicyValue.NON_RETAIN );

			policies[1] = 
				rootPOA.create_id_assignment_policy( 
					org.omg.PortableServer.IdAssignmentPolicyValue.USER_ID );
			
			policies[2] = 
				rootPOA.create_request_processing_policy( 
					org.omg.PortableServer.RequestProcessingPolicyValue.USE_SERVANT_MANAGER );

			// Create new POA
			org.omg.PortableServer.POA childPOA = rootPOA.create_POA("MyPOA", rootPOA.the_POAManager(), policies);

			// Create Servant Locator
			SrvLocator srv = new SrvLocator();

			// Set the Servant Activator to child POA
			childPOA.set_servant_manager( srv._this(orb) );

			// Create the Object ID
			byte [] servantId = ( new String("MyOwnId") ).getBytes();

			// Get the servant reference
			org.omg.CORBA.Object obj = childPOA.create_reference_with_id(servantId,"IDL:Calculatrice:1.0");

			// Transform the reference to string
			String reference = orb.object_to_string(obj);

			// Export into a file the object reference
			try
			{
				java.io.FileOutputStream file = new java.io.FileOutputStream("ObjectId");
				java.io.PrintStream pfile=new java.io.PrintStream(file);
				pfile.println(reference);
			}
			catch ( java.io.IOException ex )
			{
				System.out.println("Unable to export the server reference");
			}

			// Activate le POA by its manager way
			rootPOA.the_POAManager().activate();

			// The server is now ready
			System.out.println("The server is ready...");

			// Run and wait for invocations
			orb.run();
		}
		catch ( java.lang.Exception ex )
		{
			System.out.println("An exception has been intercepted");
			ex.printStackTrace();
		}

	}
}